API Reference
=============

.. autosummary::
   :toctree: ../modules
   :recursive:
   
   nbqol.process
   nbqol.devices
   nbqol.outputs
   nbqol.env
   nbqol.options
   nbqol.stylizer

.. note::
   For backward compatibility, some older module names are still available:

   - `nbqol.analyzer` → `nbqol.process.analyze`
   - `nbqol.convert` → `nbqol.process.reformat`
   - `nbqol.path_op` → `nbqol.env`
   - `nbqol.settings` → `nbqol.options`